@@ -1,27 +1,31 @@
 /* ncmpc (Ncurses MPD Client)
  * (c) 2004-2010 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
- 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+ */
 
-#include "options.h"
+#include <stdbool.h>
 
-int check_user_conf_dir(void);
+bool
+check_user_conf_dir(void);
 
-char *get_user_key_binding_filename(void);
+char *build_user_conf_filename(void);
+char *build_system_conf_filename(void);
 
-int read_configuration(void);
+char *build_user_key_binding_filename(void);
+
+void read_configuration(void);
 
